.. Telegram Game Framework documentation master file, created by
   sphinx-quickstart on Sun Jul 10 21:29:02 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Telegram Game Framework's documentation!
===================================================

Contents:

.. toctree::
   :maxdepth: 2

   apidoc/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
